@@ -9,7 +9,7 @@ function(object, plot.it=TRUE, ...){
     if (class(object)!="bipartite") stop("This function cannot be meaningfully applied to objects of this class.")
     N <- colSums(object)
 
-    if (all(object[,2]==1)) y <- -object[,3] else y <- -object[,2] #selects the correct column
+    if (all(object[-nrow(object), 2] == 1)) y <- -object[, 3] else y <- -object[, 2] #selects the correct column
     #y <- 100 - (sum(y)-cumsum(y))/sum(y) * 100 #ranged between 0 and 100
 
     y <- (sum(y)-cumsum(y))/sum(y)  #ranged between 0 and 1
@@ -21,14 +21,14 @@ function(object, plot.it=TRUE, ...){
 
     if(plot.it)
     {
-        par(mar=c(5,5,1,1))
+        par(mar=c(5, 5, 1, 1))
         plot(x, y, xlab="proportion of primary extinctions", ylab="proportion of species in other trophic level still alive",
             axes=TRUE, type="n", cex.lab=1.5)
-        text(0,0, paste("   killed: ", attr(object, "exterminated"), ""), font=2, cex=2, adj=0)#, line=-3)
+        text(0, 0, paste("   killed: ", attr(object, "exterminated"), ""), font=2, cex=2, adj=0)#, line=-3)
         abline(h=1)
         abline(v=1)
         points(x, y, ...)
-        lines(seq(0,1,0.1), predict(fit, newdata=data.frame(x=seq(0,1,0.1))), col="red", lwd=2)
+        lines(seq(0, 1, 0.1), predict(fit, newdata=data.frame(x=seq(0, 1, 0.1))), col="red", lwd=2)
     }
 
     return(c("exponent"=as.numeric(coef(fit)[1])))#, "coefficient"=as.numeric(coef(fit)[2])))
